@@ -4,13 +4,13 @@ testdir <- tempdir()
 
 test_that("conversion works", {
   target_name <- ace_to_fastq(filename = filename, target_dir = testdir)
-  file.info(target_name)
+  file.info(target_name$path)
 
-  expect_true(file.exists(target_name))
-  expect_true(file.info(target_name)$size > 3000)
+  expect_true(file.exists(target_name$path))
+  expect_true(file.info(target_name$path)$size > 2000)
 
-  id_expected <- "@1.seq CO Contig1 1489 2 12 U"
-  txt <- readLines(target_name)
+  id_expected <- "@1.seq CO Contig1 1475 8 156 U"
+  txt <- readLines(target_name$path)
 
   expect_true(id_expected == txt[1])
 })
@@ -20,8 +20,8 @@ test_that("id parameter works", {
     filename = filename, target_dir = testdir,
     name2id = FALSE
   )
-  id_expected <- "@CO Contig1 1489 2 12 U"
-  txt <- readLines(target_name)
+  id_expected <- "@CO Contig1 1475 8 156 U"
+  txt <- readLines(target_name$path)
 
   expect_true(id_expected == txt[1])
 })
@@ -42,3 +42,14 @@ test_that("error checks on parameters work", {
                  name2id = "x")
   )
 })
+
+
+test_that("output to stdout works", {
+  txt <- ace_to_fastq(
+    filename = filename, target_dir = 'stdout',
+    name2id = FALSE
+  )
+  id_expected <- "@CO Contig1 1475 8 156 U"
+  
+  expect_true(id_expected == txt[[1]][1])
+})
